@@ -1,7 +1,7 @@
-use once_cell::sync::Lazy;
+use std::sync::LazyLock;
 
-use super::common::{build_inverted_map, generic_alphabet_calculate_scores};
 use super::RawOutcome;
+use super::common::{build_inverted_map, generic_alphabet_calculate_scores};
 use crate::core::{FilterList, LowercaseText};
 use crate::{Lang, Script};
 
@@ -9,7 +9,8 @@ const AFR: &str = "abcdefghijklmnopqrstuvwxyzáèéêëíîïóôúû";
 const AKA: &str = "abdefghiklmnoprstuwyɔɛ";
 const AZE: &str = "abcdefghijklmnopqrstuvxyzçöüğışə̇";
 const CAT: &str = "abcdefghijklmnopqrstuvwxyz·àçèéíïòóúü";
-const CES: &str = "abcdefghijklmnopqrstuvwxyzáéóúýčďěňřšťůž";
+const CES: &str = "abcdefghijklmnopqrstuvwxyzáéíóúýčďěňřšťůž";
+const CYM: &str = "abcdefghijklmnopqrstuvwxyzàáâäèéêëìíîïòóôöùúûüýÿŵŷẁẃẅỳ";
 const DAN: &str = "abcdefghijklmnopqrstuvwxyzåæø";
 const DEU: &str = "abcdefghijklmnopqrstuvwxyzßäöü";
 const ENG: &str = "abcdefghijklmnopqrstuvwxyz";
@@ -49,6 +50,7 @@ const LATIN_ALPHABETS: &[(Lang, &str)] = &[
     (Lang::Aze, AZE),
     (Lang::Cat, CAT),
     (Lang::Ces, CES),
+    (Lang::Cym, CYM),
     (Lang::Dan, DAN),
     (Lang::Deu, DEU),
     (Lang::Eng, ENG),
@@ -83,8 +85,8 @@ const LATIN_ALPHABETS: &[(Lang, &str)] = &[
 ];
 
 /// Inverted map binding a character to a set of languages.
-pub static ALPHABET_LANG_MAP: Lazy<(Vec<char>, Vec<Vec<Lang>>)> =
-    Lazy::new(|| build_inverted_map(LATIN_ALPHABETS));
+pub static ALPHABET_LANG_MAP: LazyLock<(Vec<char>, Vec<Vec<Lang>>)> =
+    LazyLock::new(|| build_inverted_map(LATIN_ALPHABETS));
 
 pub fn alphabet_calculate_scores(text: &LowercaseText, filter_list: &FilterList) -> RawOutcome {
     generic_alphabet_calculate_scores(Script::Latin, &ALPHABET_LANG_MAP, text, filter_list)
@@ -93,8 +95,8 @@ pub fn alphabet_calculate_scores(text: &LowercaseText, filter_list: &FilterList)
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::utils::is_stop_char;
     use crate::Script;
+    use crate::utils::is_stop_char;
 
     // Old naive implementation, that is not very effective but easy to understand
     fn naive_alphabet_calculate_scores(
@@ -163,8 +165,8 @@ mod tests {
 
         let outcome = alphabet_calculate_scores(&text, &filter);
         assert_eq!(outcome.count, 50);
-        assert_eq!(outcome.raw_scores.len(), 36);
-        assert_eq!(outcome.scores.len(), 36);
+        assert_eq!(outcome.raw_scores.len(), 37);
+        assert_eq!(outcome.scores.len(), 37);
 
         let raw_scores_for = |lang: Lang| {
             outcome
