@@ -1,16 +1,17 @@
 use hashbrown::HashMap;
 
-use super::utils::{get_trigrams_with_positions, TrigramsWithPositions};
-use super::{LangProfile, LangProfileList};
-use super::{Trigram, MAX_TOTAL_DISTANCE, MAX_TRIGRAM_DISTANCE};
+use super::utils::{TrigramsWithPositions, get_trigrams_with_positions};
 use super::{ARABIC_LANGS, CYRILLIC_LANGS, DEVANAGARI_LANGS, HEBREW_LANGS, LATIN_LANGS};
-use crate::core::{calculate_confidence, FilterList, Info, InternalQuery, Text};
-use crate::scripts::grouping::MultiLangScript;
+use super::{LangProfile, LangProfileList};
+use super::{MAX_TOTAL_DISTANCE, MAX_TRIGRAM_DISTANCE, Trigram};
 use crate::Lang;
+use crate::core::{FilterList, Info, InternalQuery, Text, calculate_confidence};
+use crate::scripts::grouping::MultiLangScript;
 
 #[derive(Debug)]
 pub struct RawOutcome {
     pub trigrams_count: usize,
+    #[allow(dead_code)]
     pub raw_distances: Vec<(Lang, u32)>,
     pub scores: Vec<(Lang, f64)>,
 }
@@ -102,7 +103,7 @@ fn calculate_distance(lang_trigrams: LangProfile, text_trigrams: &HashMap<Trigra
 
     for (i, &trigram) in lang_trigrams.iter().enumerate() {
         let dist = match text_trigrams.get(&trigram) {
-            Some(&n) => (n as i32 - i as i32).abs() as u32,
+            Some(&n) => (n as i32 - i as i32).unsigned_abs(),
             None => MAX_TRIGRAM_DISTANCE,
         };
         total_dist += dist;
